==> react-bootstrap-design-0.1.2.tgz: package/src/components/watch/Hand.js <==
import React, { Component } from 'react';

class Hand extends Component {
    constructor(props) {
        super(props);

        this.state = {
            hour : null,
            minute : null,
            second : null
        }
    }

    componentWillMount() {
        var dt = new Date();

        var hour;
        if (this.props.type === 'hour') {
            hour = dt.getHours();
        }

        var minute;
        if (this.props.type === 'minute') {
            minute = dt.getMinutes();
        }

        var second;
        if (this.props.type === 'second') {
            second = dt.getSeconds();
        }

        this.setState({
            hour : hour,
            minute : minute,
            second : second
        });
    }

    componentDidMount() {
        setInterval(this.updateTime.bind(this), 1000);
    }

    updateTime() {
        var dt = new Date()
            , hour = dt.getHours()
            , minute = dt.getMinutes()
            , second = dt.getSeconds();

        this.setState(
            {
                hour : hour,
                minute : minute,
                second : second
            }
        );
    }

    render() {
        var handClasses = [
            'hand'
        ];

        var handStyles = {
            transform : '',
            zIndex : ''
        };

        var positionOffset = 90;
        // Set position to offset as default
        var handPosition = positionOffset;

        if (this.props.type === 'hour') {
            var hour = this.state.hour;
            if (hour >= 12) {
                hour = hour - 12;
            }
            if (hour === 0) {
                hour = 12;
            }
            handPosition = (hour * (360/12)) - positionOffset;
            handStyles.zIndex = 1;
        }

        if (this.props.type === 'minute') {
            var minute = this.state.minute;

            handPosition = (minute * 6) - positionOffset;
            handStyles.zIndex = 2;
        }

        if (this.props.type === 'second') {
            var second = this.state.second;

            handPosition = (second * 6) - positionOffset;
            handStyles.zIndex = 3;
        }

        handStyles.transform = 'rotate(' + handPosition + 'deg)';

        if (this.props.styles && this.props.styles.color) {
            handClasses.push(this.props.styles.color);
        }

        handClasses = handClasses.join(' ');

        return (
            <div className={handClasses} style={handStyles}></div>
        )
    }
};

export default Hand

==> react-bootstrap-design-0.3.0.tgz: package/src/components/watch/Hand.js <==
import React, { Component } from 'react';

class Hand extends Component {
    constructor(props) {
        super(props);

        this.state = {
            timezoneOffset : null,
            hour : null,
            minute : null,
            second : null
        }
    }

    componentWillMount() {
        var dt = new Date();
        var timezoneOffset = dt.getTimezoneOffset() / 60;

        var hour;
        if (this.props.type === 'hour') {
            hour = dt.getHours();
        }

        var minute;
        if (this.props.type === 'minute') {
            minute = dt.getMinutes();
        }

        var second;
        if (this.props.type === 'second') {
            second = dt.getSeconds();
        }

        this.setState({
            timezoneOffset : timezoneOffset,
            hour : hour,
            minute : minute,
            second : second
        });
    }

    componentDidMount() {
        setInterval(this.updateTime.bind(this), 1000);
    }

    updateTime() {
        var dt = new Date()
            , hour = dt.getHours()
            , minute = dt.getMinutes()
            , second = dt.getSeconds();

        this.setState(
            {
                hour : hour,
                minute : minute,
                second : second
            }
        );
    }

    render() {
        var handClasses = [
            'hand'
        ];

        var handStyles = {
            transform : '',
            zIndex : ''
        };

        var positionOffset = -90;
        var handPosition = positionOffset;

        if (this.props.type === 'hour') {
            var hour;
            if (typeof this.props.timeZone !== 'undefined') {
                hour = this.state.hour + (this.state.timezoneOffset + this.props.timeZone);
            } else {
                hour = this.state.hour;
            }

            if (hour >= 12) {
                hour = hour - 12;
            }
            if (hour === 0) {
                hour = 12;
            }
            handPosition = (hour * (360/12)) - positionOffset;
            handStyles.zIndex = 1;
        }

        if (this.props.type === 'minute') {
            var minute = this.state.minute;

            handPosition = (minute * 6) - positionOffset;
            handStyles.zIndex = 2;
        }

        if (this.props.type === 'second') {
            var second = this.state.second;

            handPosition = (second * 6) - positionOffset;
            handStyles.zIndex = 3;
        }

        handStyles.transform = 'rotate(' + handPosition + 'deg)';

        if (this.props.styles && this.props.styles.color) {
            handClasses.push(this.props.styles.color);
        }

        handClasses = handClasses.join(' ');

        return (
            <div className={handClasses} style={handStyles}></div>
        )
    }
};

export default Hand
